@@ -11,11 +11,7 @@ from .const import (
     STATE_WARM_WHITE,
 )
 from .device import LEDENETDevice
-from .protocol import (
-    ProtocolLEDENET8Byte,
-    ProtocolLEDENET9Byte,
-    ProtocolLEDENETOriginal,
-)
+from .protocol import ProtocolLEDENET8Byte, ProtocolLEDENETOriginal
 from .utils import color_temp_to_white_levels
 
 _LOGGER = logging.getLogger(__name__)
@@ -35,6 +31,7 @@ class AIOWifiLedBulb(LEDENETDevice):
         self._data_future: Optional[asyncio.Future] = None
         self._updated_callback: Optional[Callable] = None
         self._updates_without_response = 0
+        self._buffer = b""
         self.loop = asyncio.get_running_loop()
 
     async def async_setup(self, updated_callback):
@@ -129,9 +126,37 @@ class AIOWifiLedBulb(LEDENETDevice):
         """Called when the connection is lost."""
         self._aio_protocol = None
 
-    def _async_data_recieved(self, msg):
+    def _async_data_recieved(self, data):
         """New data on the socket."""
+        start_empty_buffer = not self._buffer
+        self._buffer += data
         self._updates_without_response = 0
+        # Some of the older bulbs respond to a state request in
+        # multiple packets so we have to reassemble.  Currently
+        # we only know how to reassemble state responses
+        if (
+            # if the buffer has the start of a state response
+            self._protocol.is_start_of_state_response(self._buffer)
+            # If the buffer does not have a full state response
+            and not self._protocol.is_valid_state_response(self._buffer)
+            # .. and the buffer is not longer than the a valid state response
+            and not self._protocol.is_longer_than_state_response(self._buffer)
+        ):
+            # We wait for more data. Otherwise we process the message
+            return
+        msg = self._buffer
+        self._buffer = b""
+        if not start_empty_buffer:
+            _LOGGER.debug(
+                "%s <= Reassembled (%s) (%d)",
+                self._aio_protocol.peername,
+                " ".join(f"0x{x:02X}" for x in msg),
+                len(msg),
+            )
+        self._async_process_message(msg)
+
+    def _async_process_message(self, msg):
+        """Process a full message (maybe reassembled)."""
         if self._data_future and not self._data_future.done():
             self._data_future.set_result(msg)
             return
@@ -158,7 +183,7 @@ class AIOWifiLedBulb(LEDENETDevice):
     async def _async_determine_protocol(self):
         # determine the type of protocol based of first 2 bytes.
         for protocol_cls in (ProtocolLEDENET8Byte, ProtocolLEDENETOriginal):
-            protocol = protocol_cls()
+            self._protocol = protocol = protocol_cls()
             async with self._lock:
                 await self._async_connect()
                 self._data_future = asyncio.Future()
@@ -175,11 +200,7 @@ class AIOWifiLedBulb(LEDENETDevice):
                     # cannot process, recycle the connection
                     self._aio_protocol.close()
                     continue
-                # Devices that use an 9-byte protocol
-                if self._uses_9byte_protocol(full_msg[1]):
-                    self._protocol = ProtocolLEDENET9Byte()
-                else:
-                    self._protocol = protocol
+                self._set_protocol_from_msg(full_msg, protocol)
                 self.process_state_response(full_msg)
                 return
         raise RuntimeError("Cannot determine protocol")
